| Title: | A Comprehensive R Tool for Zootechnical Metrics |
|---|---|
| Description: | A collection of functions to compute frequently used metrics for nutrition trials in aquaculture. Implementations include metrics to calculate growth, feed conversion, nutrient use efficiency, and feed digestibility. The package supports reproducible workflows for summarising experimental results and reduces manual calculation errors. For additional information see Machado e Silva, Karthikeyan and Tellbüscher (2025) <doi:10.13140/RG.2.2.27322.04808>. |
| Authors: | Anıl Axel Tellbüscher [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-6065-9494>), Davide Machado e Silva [aut] (ORCID: <https://orcid.org/0000-0003-2892-8292>), Simão Correia [aut] (ORCID: <https://orcid.org/0000-0003-2877-0317>), Madhav Karthikeyan [ctb] (ORCID: <https://orcid.org/0000-0002-1284-4652>), Tomáš Pěnka [dtc] (ORCID: <https://orcid.org/0000-0002-5923-3242>) |
| Maintainer: | Anıl Axel Tellbüscher <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.1.2 |
| Built: | 2026-05-10 05:29:40 UTC |
| Source: | https://github.com/tellanax/aquacultur |
Function to calculate the Apparent Digestibility Coefficient (ADC) of the dry matter fraction of a compound diet.
adc_dm(std_diet, dm_diet = 1, std_feces)adc_dm(std_diet, dm_diet = 1, std_feces)
std_diet |
a numeric value, resembling the inclusion rate of standard in the experimental feed given to the livestock. |
dm_diet |
a numeric value in the interval [0, 1], being the dry matter content of the feed. The default is 1 gram per gram |
std_feces |
a numeric value, resembling the inclusion rate of standard in the feces recovered during the digestibility trial. |
returns a single numeric value in the interval [0, 1], which is the relative ADC for the dry matter content of the diet. If the value is not within the interval, an additional warning is returned.
Anıl Axel Tellbüscher
Bureau, D. P., Harris, A. M. & Cho, C. Y. (1999): Apparent digestibility of rendered animal protein ingredients for rainbow trout (Oncorhynchus mykiss). Aquaculture, 180, p.345-358.
# use function to calculate a single ADC value # 900 g/kg (90%) dry matter content of feed # 10 g/kg (1%) digestibility standard in feed # 45 g/kg (4.5%) digestibility standard in feces adc_dm(dm_diet = 0.95, std_diet = 0.01, std_feces = 0.045) # function can also be used within a tidyverse pipeline. digestdm %>% dplyr::group_by(diet) %>% dplyr::summarise( `ADC DM` = adc_dm(dm = dm, std_diet = std_feed, std_feces = std_feces))# use function to calculate a single ADC value # 900 g/kg (90%) dry matter content of feed # 10 g/kg (1%) digestibility standard in feed # 45 g/kg (4.5%) digestibility standard in feces adc_dm(dm_diet = 0.95, std_diet = 0.01, std_feces = 0.045) # function can also be used within a tidyverse pipeline. digestdm %>% dplyr::group_by(diet) %>% dplyr::summarise( `ADC DM` = adc_dm(dm = dm, std_diet = std_feed, std_feces = std_feces))
Function to calculate the Apparent Digestibility Coefficient of a nutrient contained in a feed ingredient of a compound diet. The calculation of the ADCingr is based on equation 4 proposed by Bureau & Hua (2006).
adc_ingr( adc_test, adc_ref, nut_ref, nut_ingr, dm_ref = 1, dm_ingr = 1, incl_ingr = 0.3 )adc_ingr( adc_test, adc_ref, nut_ref, nut_ingr, dm_ref = 1, dm_ingr = 1, incl_ingr = 0.3 )
adc_test |
a numeric value in the interval [0,1] that represents the Apparent Digestibility Coefficient (ADC) of the diet that contains the ingredient to be tested. |
adc_ref |
a numeric value in the interval [0,1] that represents the Apparent Digestibility Coefficient (ADC) of the reference diet without the ingredient to be tested. |
nut_ref |
a numeric value in the interval [0,1] that represents the inclusion rate of the nutrient in the reference diet. |
nut_ingr |
a numeric value in the interval [0,1] that represents the inclusion rate of the nutrient in the test diet for which the Apparent Digestibility Coefficient (ADC) of the nutrient in the ingredient will be calculated. |
dm_ref |
a numeric value in the interval [0,1] (default: 1) that represents the dry matter content of the reference diet. |
dm_ingr |
a numeric value in the interval [0,1] (default: 1) that represents the dry matter content of the tested feed ingredient. |
incl_ingr |
a numeric value in the interval [0,1] (default: 0.3) that represents the inclusion rate of the ingredient in the test diet for which the Apparent Digestibility Coefficient (ADC) of the nutrient in an ingredient will be calculated. |
returns a single numeric value in the interval [0, 1], which is the relative ADC for the diet. If the value is not within the interval, an additional warning is returned.
Anıl Axel Tellbüscher
Bureau, D. P., & Hua, K. (2006): Letter to the Editor of Aquaculture. Aquaculture, 252, p.103–105.
Bureau, D. P., Harris, A. M., & Cho, C. Y. (1999): Apparent digestibility of rendered animal protein ingredients for rainbow trout (Oncorhynchus mykiss). Aquaculture 180, p.345-358.
# Example from Bureau et al. (1999) - Blood meal 2 # reference feed dry matter: 0.928 (92.8%) # reference feed nutrient mass frac.: 0.45 (45%) # reference feed apparent digestibility coef.: 0.923 (92.3%) # test feed apparent digestibility coef.: 0.902 (90.2%) # test ingredient dry matter: 0.895 (89.5%) # test ingredient nutrient mass frac.: 0.846 (84.6%) adc_ingr(adc_ref = 0.923, nut_ref = 0.45, dm_ref = 0.928, adc_test = 0.902, nut_ingr = 0.846, dm_ingr = 0.895)# Example from Bureau et al. (1999) - Blood meal 2 # reference feed dry matter: 0.928 (92.8%) # reference feed nutrient mass frac.: 0.45 (45%) # reference feed apparent digestibility coef.: 0.923 (92.3%) # test feed apparent digestibility coef.: 0.902 (90.2%) # test ingredient dry matter: 0.895 (89.5%) # test ingredient nutrient mass frac.: 0.846 (84.6%) adc_ingr(adc_ref = 0.923, nut_ref = 0.45, dm_ref = 0.928, adc_test = 0.902, nut_ingr = 0.846, dm_ingr = 0.895)
Function to calculate the Apparent Digestibility Coefficient of a nutrient in the dry matter fraction of a compound diet.
adc_nut(std_diet, std_feces, nut_diet, nut_feces)adc_nut(std_diet, std_feces, nut_diet, nut_feces)
std_diet |
numeric; value resembling the inclusion rate of standard in the experimental diet given to the livestock. |
std_feces |
numeric; value resembling the inclusion rate of standard in the feces recovered during the digestibility trial. |
nut_diet |
numeric; value representing the inclusion rate of the target nutrient in the diet. |
nut_feces |
numeric; value representing the inclusion rate of the target nutrient in the feces. |
returns a single numeric value in the interval [0, 1] which is the relative ADC for a single nutrient in the diet. If the value is not within the interval, an additional warning is returned.
Anıl Axel Tellbüscher
Bureau, D.P., & Hua, K. (2006): Letter to the Editor of Aquaculture. Aquaculture, 252, p.103–105.
Cho, C.Y., Slinger, S.J., & Bayley, H.S. (1982): Bioenergetics of salmonid fishes: energy intake, expenditure and productivity. Comp. Biochem. Physiol. 73B, p.25–41.
# 0.4 g/g (40%) CP on dry matter basis in feed # 0.1 g/g (10%) CP on dry matter basis in feces # 0.010 g/g (1%) digestibility standard in feed # 0.045 g/g (4.5%) digestibility standard in feces adc_nut(nut_diet = 0.4, nut_feces = 0.1, std_diet = 0.01, std_feces = 0.045)# 0.4 g/g (40%) CP on dry matter basis in feed # 0.1 g/g (10%) CP on dry matter basis in feces # 0.010 g/g (1%) digestibility standard in feed # 0.045 g/g (4.5%) digestibility standard in feces adc_nut(nut_diet = 0.4, nut_feces = 0.1, std_diet = 0.01, std_feces = 0.045)
A function that calculates the Absolute Growth (AG), also denoted as Absolute Weight Gain (AWG) based on the Initial Body weight (IBW; ibw) in gram (g) and the Final Body Weight (FBW; fbw) in gram (g).
ag(ibw, fbw) weight_gain(ibw, fbw)ag(ibw, fbw) weight_gain(ibw, fbw)
ibw |
numeric; value providing the initial bodyweight in grams. |
fbw |
numeric; value providing the final bodyweight in grams. |
returns a numeric value that is the AG.
Anıl Axel Tellbüscher
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
data(weight2) dplyr::mutate(weight2, AG = ag(ibw_g, fbw_g))data(weight2) dplyr::mutate(weight2, AG = ag(ibw_g, fbw_g))
A function that calculates the Absolute Growth Rate (AGR), also denoted as Weight Gain (WG) when applied to weight data.
agr(ibw, fbw, duration)agr(ibw, fbw, duration)
ibw |
numeric; value that is providing the initial body weight in grams. |
fbw |
numeric; value that is providing the final body weight in grams. |
duration |
numeric value that is providing the duration of the experiment in days. |
returns a numeric value which is the total body weight change over the specified period of time.
Anıl Axel Tellbüscher
Madhav Karthikeyan
Davide A. Machado e Silva
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
Hopkins K.D. (1992) Reporting fish growth, a review of the basics. Journal of World Aquaculture Society, 23, p.173-179
data(weight2) dplyr::mutate(weight2, AGR = agr(ibw_g, fbw_g, duration = 84))data(weight2) dplyr::mutate(weight2, AGR = agr(ibw_g, fbw_g, duration = 84))
This dataset contains compositional data on the proximate composition and some key minerals in the body of Atlantic salmon (Salmo salar) at the beginning and the end of a trial. The original dataset ('BodyComposition_tank') was published by Liland et al. (2024) and is from the first out of two trials ('Trial A'). Alterations to the original data structure were done by 1) converting the double-row column names into single-row column names and 2) removing the 'sex' column.
A tibble with 12 rows and 14 columns:
date; date of data recording.
factor; treatment identifier.
factor; rearing tank identifier.
numeric; dry matter content of fish tissue in g/g.
numeric; content of fish tissue in g/g.
numeric; content of fish tissue in g/g on dry matter basis.
numeric; gross energy content of fish tissue in kJ/g on dry matter basis.
numeric; crude fat content of fish tissue in g/g on dry matter basis.
numeric; crude protein content of fish tissue in g/g on dry matter basis.
numeric; calcium content of fish tissue in mg/kg on dry matter basis.
numeric; potassium content of fish tissue in mg/kg on dry matter basis.
numeric; magnesium content of fish tissue in mg/kg on dry matter basis.
numeric; sodium content of fish tissue in mg/kg on dry matter basis.
numeric; content of fish tissue in mg/kg on dry matter basis.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
bodycompbodycomp
This dataset contains example data to calculate the apparent digestibility of two diets that differ in their dry matter mass fraction and in the mass fraction of digestibility markers in the feces.
A tibble with two rows and four columns:
character; feed identifier.
numeric; mass fraction of dry matter in the feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feces. Data reported as value between 0 and 1, corresponding to g/g.
digestdmdigestdm
This dataset contains example data for the determination of the apparent digestibility of feed ingredients by using a reference diet and replacing a part (usually 30 The dataset is based on Bureau et al. (1999) but was presented in its complete form in Bureau & Hua (2006).
A tibble with one row and eight columns
character; reference feed identifier.
character; feed ingredient identifier.
numeric; apparent digestibility coefficient of the reference feed. The data is a value between 0 and 1.
numeric; apparent digestibility coefficient of the test feed. The data is a value between 0 and 1.
numeric; mass fraction of dry matter in the reference feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of dry matter in the feed ingredient. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of crude protein in the pelleted reference feed reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of crude protein in the feed ingredient. Data reported as value between 0 and 1, corresponding to g/g.
Bureau, D. P. & Hua, K. (2006). Letter to the Editor of Aquaculture. Aquaculture, 252(2-4), 103–105. https://doi.org/10.1016/j.aquaculture.2006.01.028
Bureau, D. P., Harris, A. M. & Cho, C. Y. (1999). Apparent digestibility of rendered animal protein ingredients for rainbow trout (Oncorhynchus mykiss). Aquaculture, 180, 345–358. https://doi.org/10.1016/S0044-8486(99)00210-0
digestingrdigestingr
This dataset contains example data for the calculation of apparent digestibility coefficients for the digestibility of nitrogen in the dry matter fraction of an aquaculture feed.
A tibble with two rows and six columns:
character; feed identifier.
numeric; mass fraction of dry matter in the feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of nitrogen in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of digestibility marker in feed. Data reported as value between 0 and 1, corresponding to g/g.
numeric; mass fraction of nitrogen in feces in g/kg.
numeric; mass fraction of digestibility marker in feces. Data reported as value between 0 and 1, corresponding to g/g.
digestnutdigestnut
A function that calculates the feed conversion efficiency (FCE), which is the inverse of the feed conversion ratio (FCR). As FCR, this metric measures how effectively cultivated species convert feed into weight. However, contrarily to FCR, the higher the FCE the more efficient the feed conversion is.
fce(ibw, fbw, feed, dm = 1)fce(ibw, fbw, feed, dm = 1)
ibw |
numeric; value that is providing the initial body weight in grams. |
fbw |
numeric; value that is providing the final body weight in grams. |
feed |
numeric; value providing the total feed fed in grams during the experiment. |
dm |
numeric; value indicating the dry matter content of the feed. Value in the interval of (0:1). Default is 1. |
a numeric value that is the feed conversion efficiency (FCE)
Anıl Axel Tellbüscher
Davide A. Machado e Silva
Madhav Karthikeyan
# Feed intake = 1500 g # Feed dry matter = 0.96 g/g (= 96%) # Initial bodyweight = 100 g # Final bodyweight = 1000 g fce(100, 1000, 1500, 0.96)# Feed intake = 1500 g # Feed dry matter = 0.96 g/g (= 96%) # Initial bodyweight = 100 g # Final bodyweight = 1000 g fce(100, 1000, 1500, 0.96)
A function that calculates the Feed Conversion Ratio (FCR) based on the Initial Body weight (IBW; ibw) in gram (g), the Final Body Weight (FBW; fbw) in gram (g), the Feed fed (Ff; ff) in gram and the dry matter (DM; dm) content of the feed in percent.
fcr(ibw, fbw, feed, dm = 1)fcr(ibw, fbw, feed, dm = 1)
ibw |
numeric; value that is providing the initial weight in grams. |
fbw |
numeric; value that is providing the final weight in grams. |
feed |
numeric; value providing the feed fed in grams during the experiment. |
dm |
numeric; value within the interval of ]0:1], indicating the relative dry matter content of the feed. |
The Feed Conversion Ratio (FCR) describes the amount of feed on dry matter (DM) basis that is required to gain 1 kg of body weight on wet weight basis. Depending on whether the Feed fed refers to the total amount of feed administered or the total amount corrected for non-eaten feed, the result resembles the economic FCR (eFCR) or the biological FCR (bFCR), respectively (Glencross et al., 2024).
returns a numeric value that is the FCR.
Anıl Axel Tellbüscher
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
Glencross, B., Bachis, E., Robb, D., & Newton, R. (2024): The evolution of sustainability metrics for the marine ingredient sector: Moving towards holistic assessments of aquaculture feed. Reviews in Fisheries Science & Aquaculture, 32(4), p.545-561.
# Feed intake = 1500 g # Feed dry matter = 0.96 g/g (= 96%) # Initial bodyweight = 100 g # Final bodyweight = 1000 g fcr(100, 1000, 1500, 0.96)# Feed intake = 1500 g # Feed dry matter = 0.96 g/g (= 96%) # Initial bodyweight = 100 g # Final bodyweight = 1000 g fcr(100, 1000, 1500, 0.96)
This dataset contains daily feed intake data from a feeding trial with Atlantic salmon (Salmo salar). The original dataset ("FeedIntake") was published by Liland et al. (2024) and is from the first out of two trials ("Trial A"). Alterations to the original data structure were done by 1) converting the double-row column names into single-row column names, 2) shortening the column names, and 3) converting the table into long format by moving the tank IDs into a separate column. NA values have been replaced by the recalculated feed intakes for the respective day.
A tibble with 270 rows and 4 columns:
date; date of data recording.
factor; rearing tank identifier.
numeric; daily feed intake in gram per fish.
numeric; cumulatic feed intake in gram per fish.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
feed_intakefeed_intake
This dataset contains compositional data of Skretting Protec, a commercial fish feed. The data comprises the proximate composition, phosphorus, and some essential amino acids.
A tibble with one row and 25 columns:
character; feed name.
numeric; content of feed in g/g.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in MJ per kg as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
numeric; content of feed in g/g as fed.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
feedcompfeedcomp
This dataset contains the daily count of dead and alive fish during a 29-day feeding trial with Atlantic salmon (Salmo salar). The original dataset ('NumberOfFish') was published by Liland et al. (2024) and is from the first out of two trials ('Trial A'). Alterations to the original data structure were done by 1) converting the double-row column names into single-row column names, 2) shortening the column names, and 3) converting the table into long format by moving the tank IDs into a separate column.
A tibble with 270 rows and 4 columns:
date; date of data recording.
factor; rearing tank identifier.
numeric; count of fish stocked at the beginning of the experiment.
numeric; count of dead fish on each recorded day of the experiment.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
fishcountfishcount
A function that calculates the geometric mean of the initial and final bodyweight.
gbw(ibw, fbw)gbw(ibw, fbw)
ibw |
numeric; initial bodyweight weight in grams. |
fbw |
numeric; final bodyweight in grams. |
While the arithmetic mean assumes a linear relationship between the averaged numbers, the geometric mean accounts for the non-linear and potentially variable nature of animal growth.
numeric value that is the geometric mean bodyweight.
Anıl Axel Tellbüscher
data(weight2) dplyr::mutate(weight2, GMBW = gbw(ibw_g, fbw_g))data(weight2) dplyr::mutate(weight2, GMBW = gbw(ibw_g, fbw_g))
The metabolic bodyweight is the rate of energy expenditure in dependence of the bodyweight of an organism. The metabolism of larger animals is generally slower per Kg when comparing with smaller animals. An exponent between 0-1 takes that relationship into account in a fairly simple equation.
mbw(ibw, fbw, mb_exp = 0.8)mbw(ibw, fbw, mb_exp = 0.8)
ibw |
a numeric value that is providing the initial weight in grams. |
fbw |
a numeric value that is providing the final weight in grams. |
mb_exp |
a numeric value between 0-1 providing the exponent. Default is 0.8 adapted to most fish species. |
The default exponent is suited to fish only. It was set to 0.8 based on Lupatsch et al. (2003) and should be adjusted to other scenarios.
returns a numeric value that is the metabolic bodyweight.
Anıl Axel Tellbüscher
Davide A. Machado e Silva
Madhav Karthikeyan
Lupatsch, I. et al. (2003): Comparison of energy and protein efficiency among three fish species gilthead sea bream (Sparus aurata), European sea bass (Dicentrarchus labrax) and white grouper (Epinephelus aeneus): energy expenditure for protein and lipid deposition. Aquaculture 225, p.175-189.
data(weight2) dplyr::mutate(weight2, MBW = mbw(ibw_g, fbw_g))data(weight2) dplyr::mutate(weight2, MBW = mbw(ibw_g, fbw_g))
Function to calculate the Nutrient Efficiency Ratio (NER). The NER belongs to the Nutrient Use Efficiency metrics and relates the intake of a compound with the bodyweight increase. If the feed intake (FI) is restricted and the administered diets are of comparable digestibility, then potential differences in growth could be related to differences in the sub-composition of target nutrients that are also controlled for. This would be reflected by the NER.
ner(ibw, fbw, fi, nut_f, dm = 1)ner(ibw, fbw, fi, nut_f, dm = 1)
ibw |
a numeric value for the initial weight (either average weight of the individuals or the total biomass) of the livestock at the beginning of the feeding trial. |
fbw |
a numeric value for the final weight (either average weight of the individuals or the total biomass) of the livestock at the end of the feeding trial. |
fi |
numeric; value providing the total feed intake in grams during the experiment. |
nut_f |
numeric; value within the interval of (0,1), indicating the inclusion rate of the nutrient of interest in the feed fed. |
dm |
numeric; value within the interval of (0,1), indicating the dry matter content of the feed. Default is 1 (100%). |
returns a single numeric value
Anıl Axel Tellbüscher
# Initial bodyweight = 10 g # Final bodyweight = 100 g # Feed intake = 240 g # Nutrient mass fraction in feed = 0.5 g/g ner(ibw = 10, fbw = 100, fi = 240, nut_f = 0.5)# Initial bodyweight = 10 g # Final bodyweight = 100 g # Feed intake = 240 g # Nutrient mass fraction in feed = 0.5 g/g ner(ibw = 10, fbw = 100, fi = 240, nut_f = 0.5)
Function to calculate the Nutrient Retention (NR). The NR belongs to the Nutrient Use Efficiency metrics and is a measure for the proportion of a consumed nutrient that is retained in the tissue.
nr(ibw, fbw, ibn, fbn, fi, nut_f, dm = 1, dm_ib = 1, dm_fb = 1)nr(ibw, fbw, ibn, fbn, fi, nut_f, dm = 1, dm_ib = 1, dm_fb = 1)
ibw |
numeric; initial weight in grams |
fbw |
numeric; final weight in grams |
ibn |
numeric; initial mass fraction of the target nutrient in the tissue of the experimental animal (on dry matter basis). The value must be between 0 and 1. |
fbn |
numeric; final mass fraction of the target nutrient in the tissue of the experimental animal (on dry matter basis). The value must be between 0 and 1. |
fi |
numeric; mass of feed given. |
nut_f |
numeric; mass fraction of nutrient in the diet. The value must be between 0 and 1. |
dm |
numeric; dry matter content of feed. Default is 1. |
dm_ib |
numeric; initial dry matter content of body tissue. Default is 1. |
dm_fb |
numeric; final dry matter content of body tissue. Default is 1. |
a numeric value. Multiply by 100 to convert into percentage.
Anıl Axel Tellbüscher
Willer, D.F., Newton, R., Malcorps, W. et al. Wild fish consumption can balance nutrient retention in farmed fish. Nat Food 5, 221–229 (2024). https://doi.org/10.1038/s43016-024-00932-z
# initial bodyweight = 10 g (0.01 kg) # final bodyweight = 100 g (0.1 kg) # initial mass fraction of N = 128 g/kg (80% CP on DM basis) # final mass fraction of N = 132 g/kg (82.5% CP on DM basis) # feed intake = 200 g (0.2 kg) # N in feed = 72 g/kg (45% CP) nr(10, 100, 0.128, 0.132, 200, 0.072) * 100 # 82.7% of the provided N has been retained # multiple fish nr(ibw = 10, fbw = c(93, 102, 99, 98, 101, 132), ibn = 0.128, fbn = 0.132, fi = 200, nut_f = 0.072)# initial bodyweight = 10 g (0.01 kg) # final bodyweight = 100 g (0.1 kg) # initial mass fraction of N = 128 g/kg (80% CP on DM basis) # final mass fraction of N = 132 g/kg (82.5% CP on DM basis) # feed intake = 200 g (0.2 kg) # N in feed = 72 g/kg (45% CP) nr(10, 100, 0.128, 0.132, 200, 0.072) * 100 # 82.7% of the provided N has been retained # multiple fish nr(ibw = 10, fbw = c(93, 102, 99, 98, 101, 132), ibn = 0.128, fbn = 0.132, fi = 200, nut_f = 0.072)
A dataset containing feed quantities fed per tank and the average water temperature over all tanks stocked with pikeperch oder sturgeon. The variables are as follows:
A data frame containing 24 rows and four columns:
character; unique identifier for each fish tank.
numeric; total feed input in gram over the duration of the experiment.
numeric; average water temperature in degrees Celsius.
numeric; total duration of the experiment in days.
rearingrearing
A function that calculates the Relative Growth (RG) based on the Initial Body weight (IBW; ibw) and the Final Body Weight (FBW; fbw) in grams (g).
rg(ibw, fbw)rg(ibw, fbw)
ibw |
numeric; value providing the initial weight in grams. |
fbw |
numeric; value providing the final weight in grams. |
returns a numeric value that is the Relative Growth. Multiply by 100 for conversion into a percentage.
Anıl Axel Tellbüscher
data(weight2) dplyr::mutate(weight2, RG = rg(ibw_g, fbw_g))data(weight2) dplyr::mutate(weight2, RG = rg(ibw_g, fbw_g))
A function that calculates the Relative Growth Rate (RGR), which is the relative weight increase per time unit.
rgr(ibw, fbw, duration, mean_fun = "init")rgr(ibw, fbw, duration, mean_fun = "init")
ibw |
numeric; provides the initial weight in gram. |
fbw |
numeric; provides the final weight in gram. |
duration |
numeric; duration of the growth experiment. |
mean_fun |
character; specifies how ("init", "geometric" or "arithmetic") to calculate the denominator. Default: "init". |
either a single numeric value or vector holding the calculated RGR values. Multiply by 100 for conversion into percentage.
Anıl Axel Tellbüscher
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
data(weight2) dplyr::mutate(weight2, RGR = rgr(ibw_g, fbw_g, duration = 84))data(weight2) dplyr::mutate(weight2, RGR = rgr(ibw_g, fbw_g, duration = 84))
This dataset contains the fish weight, fork length, sex, liver weight, hepatosomatic index, heart weight, cardiosomatic index, gonad weight, gonadosomatic index, viscera weight, and viscerosomatic index from a feeding trial with Atlantic salmon (Salmo salar). The original dataset ('FeedIntake') was published by Liland et al. (2024) and is from the first out of two trials ('Trial A'). Alterations to the original data structure were done by 1) converting the double-row column names into single-row column names, and 2) removing the 'sex' column.
A tibble with 181 rows and 14 columns:
date; date of data recording.
factor; rearing tank identifier.
factor; replicate identifier.
factor; type of sample.
numeric; weight of fish in gram.
numeric; length of fish from the tip of the snout to the end of the middle caudal fin rays in centimeter.
numeric; weight of the liver in gram.
numeric; hepatosomatic index in percent.
numeric; weight of the heart in gram.
numeric; cardiosomatic index in percent.
numeric; weight of the gonads in gram.
numeric; gonadosomatic index in percent.
numeric; weight of the viscera in gram.
numeric; viscerosomatic index in percent.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
samplingssamplings
This function calculates the Specific Growth Rate (SGR) based on the Instantaneous Growth Rate (IGR). The IGR is a useful metric, although hard to interpret. The SGR, derived from IGR, can then be easily interpreted as the percentage of Body Weight gained each day. The SGR is a growth metric for aquaculture products (e.g., fish, crustaceans, bivalves, algae), describing the increase in body weight over a period of time. Body weight can be substituted by other metrics, such as length. However, body weight is the used in the vast majority of studies and alternatives are not advised for the sake of consistency.
sgr(ibw, fbw, duration, return_igr = FALSE)sgr(ibw, fbw, duration, return_igr = FALSE)
ibw |
numeric; value that is providing the initial body weight in grams. |
fbw |
numeric; value that is providing the final body weight in grams. |
duration |
numeric value that is providing the duration of the experiment in days. |
return_igr |
logical; default is FALSE. Indicates whether the instantaneous growth rate shall be returned together with the SGR or not. |
Returns a numeric, which is the SGR as percentage of the body weight gain per day, or a list containing the SGR and the IGR.
Anıl Axel Tellbüscher
Davide A. Machado e Silva
Crane, D.P., Ogle, D.H. and Shoup, D.E. (2020), Use and misuse of a common growth metric: guidance for appropriately calculating and reporting specific growth rate. Rev Aquacult, 12: 1542-1547. https://doi.org/10.1111/raq.12396
dplyr::mutate(weight2, SGR = sgr(ibw_g, fbw_g, duration = 84))dplyr::mutate(weight2, SGR = sgr(ibw_g, fbw_g, duration = 84))
A function that calculates Thermal Growth Coefficient (TGC) based on the Initial Body weight (IBW) in grams (g), the Final Body Weight (FBW) in grams (g) and the average water temperature (Temp.) in Celsius (°C) for the duration of the trial.
The TGC is an alternative growth metric for fishes, describing the increase in bodyweight over a period of time. It is suitable for poikilothermic animals due to its standardisation for temperature. It should, however, be taken into account, that the temperature during the experiment should remain within the optimum range. It is also noteworthy that the equation is optimized for a constant temperature throughout the experiment.
tgc(ibw, fbw, duration, temp, scale_coef = 1000)tgc(ibw, fbw, duration, temp, scale_coef = 1000)
ibw |
a numeric value that is providing the initial body weight in grams. |
fbw |
a numeric value that is providing the final body weight in grams. |
duration |
a numeric value that is providing the duration of the experiment in days. |
temp |
a numeric value that is providing the average temperature during the experiment in degrees Celsius. |
scale_coef |
Scaling coefficient. A numeric value that scales the TGC result so it is more intuitive and interpretable. Default is 1000. |
Returns a numeric value that is the TGC.
Anıl Axel Tellbüscher
Davide A. Machado e Silva
Madhav Karthikeyan
Lugert, V., Thaller, G., Tetens, J., Schulz, C., & Krieter, J. (2016): A review on fish growth calculation: multiple functions in fish production and their specific application. Reviews in Aquaculture, 8, p.30–42.
Jobling, M. (2003): The thermal growth coefficient (TGC) model of fish growth: a cautionary note. Aquaculture Research, 34, p. 581–584.
This dataset contains the rearing tank and respective treatment assigned to it. It represents the metadata from a feeding trial with Atlantic salmon (Salmo salar). The related dataset was published by Liland et al. (2024) and is from the first out of two trials ("Trial A").
A tibble with nine rows and two columns:
factor; rearing tank identifier.
factor; treatment identifier.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
treatmentstreatments
This dataset contains daily readings of water temperature, salinity, and dissolved oxygen from a feeding trial with Atlantic salmon (Salmo salar). The original dataset ("WaterParametersDaily") was published by Liland et al. (2024) and is from the first out of two trials ("Trial A"). Alterations to the original data structure were done by 1) converting the double-row column names into single-row column names, 2) shortening the column names, and 3) converting the table into long format by moving the tank IDs into a separate column.
A tibble with 270 rows and 6 columns:
date; date of data recording.
factor; rearing tank identifier.
numeric; water temperature in degrees Celsius.
numeric; salinity in parts per thousand.
numeric; dissolved oxygen in percentage saturation.
numeric; dissolved oxygen concentration in mg/L.
Liland, N., Rønnestad, I., Azevedo, M., Lai, F., Oulie, F., Conceição, L., Soares, F. (2024): Dataset on the performance of Atlantic salmon (Salmo salar) reared at different dissolved oxygen levels under experimental conditions. Data in Brief 57, 110983. https://doi.org/10.1016/j.dib.2024.110983
water_paramswater_params
A dataset containing fish weights from a polyculture experiment with pikeperch (Sander lucioperca) and Russian sturgeon.
A tibble with 24 rows and eight columns:
character; rearing tank identifier.
character; treatment identifier.
numeric; fish count at the beginning of the experiment.
numeric; fish count at the end of the experiment.
numeric; total fish biomass in kg at the beginning of the experiment.
numeric; total fish biomass in kg at the end of the experiment.
weightweight
A dataset holding weight data of tagged individuals of two different fish species, pikeperch (Sander lucioperca) and largemouth bass (Micropterus salmoides), at the beginning and the end of a polyculture experiment for aquaculture purposes.
A tibble with 396 rows and four columns:
character; species identifier.
character; culture system identifier.
numeric; initial bodyweight in gram.
numeric; final bodyweight in gram.
Pěnka T., Malinovskyi O., Křišťan J., Imentai A., Policar T. (2021): Effect of density and mixed culture with pikeperch (Sander lucioperca) on effectivity of largemouth bass (Micropterus salmoides) intensive culture. Czech Journal of Animal Science, 66: 428–440.
weight2weight2